@@ -12,9 +12,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import inspect
 import tornado.web
-import typing
 import json
 import pytz
 import cloudevents.exceptions as ce
@@ -22,8 +20,11 @@ from cloudevents.http import CloudEvent, from_http, is_binary, is_structured, to
 from cloudevents.sdk.converters.util import has_binary_headers
 from http import HTTPStatus
 from kfserving.kfmodel_repository import KFModelRepository
+from kfserving.kfmodel import ModelType
 from datetime import datetime
 
+from ray.serve.api import RayServeHandle
+
 
 class HTTPHandler(tornado.web.RequestHandler):
     def initialize(self, models: KFModelRepository):
@@ -36,30 +37,22 @@ class HTTPHandler(tornado.web.RequestHandler):
                 status_code=HTTPStatus.NOT_FOUND,
                 reason="Model with name %s does not exist." % name
             )
-        if not model.ready:
+        if not self.models.is_model_ready(name):
             model.load()
         return model
 
-    def validate(self, request):
-        if(isinstance(request, dict)):
-            if ("instances" in request and not isinstance(request["instances"], list)) or \
-               ("inputs" in request and not isinstance(request["inputs"], list)):
-                raise tornado.web.HTTPError(
-                    status_code=HTTPStatus.BAD_REQUEST,
-                    reason="Expected \"instances\" or \"inputs\" to be a list"
-                )
-        return request
 
 class PredictHandler(HTTPHandler):
     async def post(self, name: str):
-        if has_binary_headers(self.request.headers):            
+        if has_binary_headers(self.request.headers):
             try:
-                #Use default unmarshaller if contenttype is set in header
+                # Use default unmarshaller if contenttype is set in header
                 if "ce-contenttype" in self.request.headers:
                     body = from_http(self.request.headers, self.request.body)
                 else:
                     body = from_http(self.request.headers, self.request.body, lambda x: x)
-            except (ce.MissingRequiredFields, ce.InvalidRequiredFields, ce.InvalidStructuredJSON, ce.InvalidHeadersFormat, ce.DataMarshallerError, ce.DataUnmarshallerError) as e:
+            except (ce.MissingRequiredFields, ce.InvalidRequiredFields, ce.InvalidStructuredJSON,
+                    ce.InvalidHeadersFormat, ce.DataMarshallerError, ce.DataUnmarshallerError) as e:
                 raise tornado.web.HTTPError(
                     status_code=HTTPStatus.BAD_REQUEST,
                     reason="Cloud Event Exceptions: %s" % e
@@ -72,13 +65,14 @@ class PredictHandler(HTTPHandler):
                     status_code=HTTPStatus.BAD_REQUEST,
                     reason="Unrecognized request format: %s" % e
                 )
-
+        # call model locally or remote model workers
         model = self.get_model(name)
-        request = model.preprocess(body)
-        request = self.validate(request)
-        response = (await model.predict(request)) if inspect.iscoroutinefunction(model.predict) else model.predict(request)
-        response = model.postprocess(response)
-
+        if not isinstance(model, RayServeHandle):
+            response = await model(body)
+        else:
+            model_handle = model
+            response = await model_handle.remote(body)
+        # process response from the model
         if has_binary_headers(self.request.headers):
             event = CloudEvent(body._attributes, response)
             if is_binary(self.request.headers):
@@ -88,8 +82,9 @@ class PredictHandler(HTTPHandler):
             for k, v in eventheader.items():
                 if k != "ce-time":
                     self.set_header(k, v)
-                else: #utc now() timestamp
-                    self.set_header('ce-time', datetime.utcnow().replace(tzinfo=pytz.utc).strftime('%Y-%m-%dT%H:%M:%S.%f%z'))
+                else:  # utc now() timestamp
+                    self.set_header('ce-time', datetime.utcnow().replace(tzinfo=pytz.utc).
+                                    strftime('%Y-%m-%dT%H:%M:%S.%f%z'))
             response = eventbody
 
         self.write(response)
@@ -97,7 +92,6 @@ class PredictHandler(HTTPHandler):
 
 class ExplainHandler(HTTPHandler):
     async def post(self, name: str):
-        model = self.get_model(name)
         try:
             body = json.loads(self.request.body)
         except json.decoder.JSONDecodeError as e:
@@ -105,8 +99,11 @@ class ExplainHandler(HTTPHandler):
                 status_code=HTTPStatus.BAD_REQUEST,
                 reason="Unrecognized request format: %s" % e
             )
-        request = model.preprocess(body)
-        request = self.validate(request)
-        response = (await model.explain(request)) if inspect.iscoroutinefunction(model.explain) else model.explain(request)
-        response = model.postprocess(response)
+        # call model locally or remote model workers
+        model = self.get_model(name)
+        if not isinstance(model, RayServeHandle):
+            response = await model(body, model_type=ModelType.EXPLAINER)
+        else:
+            model_handle = model
+            response = await model_handle.remote(body, model_type=ModelType.EXPLAINER)
         self.write(response)
