@@ -12,12 +12,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import avro.io, avro.schema, io, json, pytest, requests
+import avro.io
+import avro.schema
+import io
+import pytest
 from cloudevents.http import CloudEvent, to_binary, to_structured
 from kfserving import kfmodel
 from kfserving import kfserver
-from tornado.httpclient import HTTPClientError
 from kfserving.kfmodel_repository import KFModelRepository
+from tornado.httpclient import HTTPClientError
 
 test_avsc_schema = '''
         {
@@ -32,6 +35,7 @@ test_avsc_schema = '''
         }
         '''
 
+
 def dummy_cloud_event(data, set_contenttype=False):
     # This data defines a binary cloudevent
     attributes = {
@@ -63,6 +67,7 @@ class DummyModel(kfmodel.KFModel):
     async def explain(self, request):
         return {"predictions": request["instances"]}
 
+
 class DummyCEModel(kfmodel.KFModel):
     def __init__(self, name):
         super().__init__(name)
@@ -78,6 +83,7 @@ class DummyCEModel(kfmodel.KFModel):
     async def explain(self, request):
         return {"predictions": request["instances"]}
 
+
 class DummyAvroCEModel(kfmodel.KFModel):
     def __init__(self, name):
         super().__init__(name)
@@ -97,7 +103,7 @@ class DummyAvroCEModel(kfmodel.KFModel):
         return record1
 
     def preprocess(self, request):
-        if(isinstance(request, CloudEvent)):
+        if isinstance(request, CloudEvent):
             attributes = request._attributes
             assert attributes["specversion"] == "1.0"
             assert attributes["source"] == "https://example.com/event-producer"
@@ -108,11 +114,11 @@ class DummyAvroCEModel(kfmodel.KFModel):
 
     async def predict(self, request):
         record1 = self._parserequest(request)
-        return {"predictions": [[record1['name'] , record1['favorite_number'], record1['favorite_color']]]}
+        return {"predictions": [[record1['name'], record1['favorite_number'], record1['favorite_color']]]}
 
     async def explain(self, request):
         record1 = self._parserequest(request)
-        return {"predictions": [[record1['name'] , record1['favorite_number'], record1['favorite_color']]]}
+        return {"predictions": [[record1['name'], record1['favorite_number'], record1['favorite_color']]]}
 
 
 class DummyKFModelRepository(KFModelRepository):
@@ -130,7 +136,7 @@ class DummyKFModelRepository(KFModelRepository):
             return False
 
 
-class TestTFHttpServer():
+class TestTFHttpServer:
 
     @pytest.fixture(scope="class")
     def app(self):  # pylint: disable=no-self-use
@@ -158,7 +164,7 @@ class TestTFHttpServer():
 
     async def test_predict_ce_structured(self, http_server_client):
 
-        event = dummy_cloud_event({"instances":[[1,2]]})
+        event = dummy_cloud_event({"instances": [[1, 2]]})
         headers, body = to_structured(event)
         resp = await http_server_client.fetch('/v1/models/TestModel:predict',
                                               method="POST",
@@ -183,7 +189,7 @@ class TestTFHttpServer():
         assert resp.body == b'["TestModel"]'
 
 
-class TestTFHttpServerLoadAndUnLoad():
+class TestTFHttpServerLoadAndUnLoad:
     @pytest.fixture(scope="class")
     def app(self):  # pylint: disable=no-self-use
         server = kfserver.KFServer(registered_models=DummyKFModelRepository(test_load_success=True))
@@ -202,7 +208,7 @@ class TestTFHttpServerLoadAndUnLoad():
         assert resp.body == b'{"name": "model", "unload": true}'
 
 
-class TestTFHttpServerLoadAndUnLoadFailure():
+class TestTFHttpServerLoadAndUnLoadFailure:
     @pytest.fixture(scope="class")
     def app(self):  # pylint: disable=no-self-use
         server = kfserver.KFServer(registered_models=DummyKFModelRepository(test_load_success=False))
@@ -221,7 +227,7 @@ class TestTFHttpServerLoadAndUnLoadFailure():
         assert err.value.code == 404
 
 
-class TestTFHttpServerModelNotLoaded():
+class TestTFHttpServerModelNotLoaded:
 
     @pytest.fixture(scope="class")
     def app(self):  # pylint: disable=no-self-use
@@ -235,7 +241,8 @@ class TestTFHttpServerModelNotLoaded():
             _ = await http_server_client.fetch('/v1/models/TestModel')
         assert excinfo.value.code == 503
 
-class TestTFHttpServerCloudEvent():
+
+class TestTFHttpServerCloudEvent:
 
     @pytest.fixture(scope="class")
     def app(self):  # pylint: disable=no-self-use
@@ -245,13 +252,13 @@ class TestTFHttpServerCloudEvent():
         return server.create_application()
 
     async def test_predict_ce_binary_dict(self, http_server_client):
-        event = dummy_cloud_event({"instances":[[1,2]]}, set_contenttype=True)
+        event = dummy_cloud_event({"instances": [[1, 2]]}, set_contenttype=True)
         headers, body = to_binary(event)
         resp = await http_server_client.fetch('/v1/models/TestModel:predict',
                                               method="POST",
                                               headers=headers,
                                               body=body)
-    
+
         assert resp.code == 200
         assert resp.body == b'{"predictions": [[1, 2]]}'
         assert resp.headers['content-type'] == "application/x-www-form-urlencoded"
@@ -269,7 +276,7 @@ class TestTFHttpServerCloudEvent():
                                               method="POST",
                                               headers=headers,
                                               body=body)
-    
+
         assert resp.code == 200
         assert resp.body == b'{"predictions": [[1, 2]]}'
         assert resp.headers['content-type'] == "application/x-www-form-urlencoded"
@@ -284,25 +291,28 @@ class TestTFHttpServerCloudEvent():
         event = dummy_cloud_event(b'{', set_contenttype=True)
         headers, body = to_binary(event)
         with pytest.raises(
-            HTTPClientError, match=r".*HTTP 400: Unrecognized request format: Expecting property name enclosed in double quotes.*"
+            HTTPClientError, match=r".*HTTP 400: Unrecognized request format: "
+                                   r"Expecting property name enclosed in double quotes.*"
         ):
-            resp = await http_server_client.fetch('/v1/models/TestModel:predict',
-                                              method="POST",
-                                              headers=headers,
-                                              body=body)
+            await http_server_client.fetch('/v1/models/TestModel:predict',
+                                           method="POST",
+                                           headers=headers,
+                                           body=body)
 
     async def test_predict_ce_bytes_bad_hex_format_exception(self, http_server_client):
         event = dummy_cloud_event(b'0\x80\x80\x06World!\x00\x00', set_contenttype=True)
         headers, body = to_binary(event)
         with pytest.raises(
-            HTTPClientError, match=r".*HTTP 400: Unrecognized request format: 'utf-8' codec can't decode byte 0x80 in position 1: invalid start byte.*"
+            HTTPClientError, match=r".*HTTP 400: Unrecognized request format: "
+                                   r"'utf-8' codec can't decode byte 0x80 in position 1: invalid start byte.*"
         ):
-            resp = await http_server_client.fetch('/v1/models/TestModel:predict',
-                                              method="POST",
-                                              headers=headers,
-                                              body=body)
-    
-class TestTFHttpServerAvroCloudEvent():
+            await http_server_client.fetch('/v1/models/TestModel:predict',
+                                           method="POST",
+                                           headers=headers,
+                                           body=body)
+
+
+class TestTFHttpServerAvroCloudEvent:
 
     @pytest.fixture(scope="class")
     def app(self):  # pylint: disable=no-self-use
